@@ -1,6 +1,6 @@
 # -*- python -*-
 
-# Copyright (C) 1998-2004 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2005 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -146,6 +146,10 @@ def add_virtualhost(urlhost, emailhost=None):
 # And set the default
 add_virtualhost(DEFAULT_URL_HOST, DEFAULT_EMAIL_HOST)
 
+# Note that you will want to run bin/fix_url.py to change the domain of an
+# existing list.  bin/fix_url.py must be run within the bin/withlist script,
+# like so: bin/withlist -l -r bin/fix_url.py <listname>
+
 
 
 #####
@@ -256,6 +260,16 @@ PRIVATE_EXTERNAL_ARCHIVER = No
 # should modify the Message object as necessary.
 ARCHIVE_SCRUBBER = 'Mailman.Handlers.Scrubber'
 
+# Mailman.Handlers.Scrubber uses attachment's filename as is.
+# If you don't like this (extremely long mime-encoded filename) then set
+# this True.
+SCRUBBER_DONT_USE_ATTACHMENT_FILENAME = False
+
+# Use of attachment filename extension per se is may be dangerous because
+# virus fakes it. You can set this True if you filter the attachment by
+# filename extension
+SCRUBBER_USE_ATTACHMENT_FILENAME_EXTENSION = False
+
 # This variable defines what happens to text/html subparts.  They can be
 # stripped completely, escaped, or filtered through an external program.  The
 # legal values are:
@@ -468,6 +482,7 @@ GLOBAL_PIPELINE = [
     'Moderate',
     'Hold',
     'MimeDel',
+    'Scrubber',
     'Emergency',
     'Tagger',
     'CalcRecips',
@@ -535,7 +550,7 @@ OWNER_PIPELINE = [
 # printing of this log message.
 SMTP_LOG_EVERY_MESSAGE = (
     'smtp',
-    '%(msg_message-id)s smtp for %(#recips)d recips, completed in %(time).3f seconds')
+    '%(msg_message-id)s smtp to %(listname)s for %(#recips)d recips, completed in %(time).3f seconds')
 
 # This will only be printed if there were no immediate smtp failures.
 # Mutually exclusive with SMTP_LOG_REFUSED.
@@ -605,6 +620,8 @@ VERP_REGEXP = r'^(?P<bounces>[^+]+?)\+(?P<mailbox>[^=]+)=(?P<host>[^@]+)@.*$'
 # VERP format and regexp for probe messages
 VERP_PROBE_FORMAT = '%(bounces)s+%(token)s'
 VERP_PROBE_REGEXP = r'^(?P<bounces>[^+]+?)\+(?P<token>[^@]+)@.*$'
+# Set this Yes to activate VERP probe for disabling by bounce
+VERP_PROBES = No
 
 # A perfect opportunity for doing VERP is the password reminders, which are
 # already addressed individually to each recipient.  Set this to Yes to enable
@@ -630,7 +647,7 @@ VERP_DELIVERY_INTERVAL = 0
 # friendly Subject: on the message, but requires cooperation from the MTA.
 # Format is like VERP_FORMAT above, but with the following substitutions:
 #
-# %(confirm)s -- the list-confirm mailbox will be set here
+# %(addr)s -- the list-confirm mailbox will be set here
 # %(cookie)s  -- the confirmation cookie will be set here
 VERP_CONFIRM_FORMAT = '%(addr)s+%(cookie)s'
 
@@ -785,6 +802,21 @@ ADMIN_CATEGORIES = [
 # list's config variable default_member_moderation.
 DEFAULT_NEW_MEMBER_OPTIONS = 256
 
+# Specify the type of passwords to use, when Mailman generates the passwords
+# itself, as would be the case for membership requests where the user did not
+# fill in a password, or during list creation, when auto-generation of admin
+# passwords was selected.
+#
+# Set this value to Yes for classic Mailman user-friendly(er) passwords.
+# These generate semi-pronounceable passwords which are easier to remember.
+# Set this value to No to use more cryptographically secure, but harder to
+# remember, passwords -- if your operating system and Python version support
+# the necessary feature (specifically that /dev/urandom be available).
+USER_FRIENDLY_PASSWORDS = Yes
+# This value specifies the default lengths of member and list admin passwords
+MEMBER_PASSWORD_LENGTH = 8
+ADMIN_PASSWORD_LENGTH = 10
+
 
 
 #####
@@ -803,6 +835,7 @@ DEFAULT_MAX_MESSAGE_SIZE = 40           # KB
 # These format strings will be expanded w.r.t. the dictionary for the
 # mailing list instance.
 DEFAULT_SUBJECT_PREFIX  = "[%(real_name)s] "
+# DEFAULT_SUBJECT_PREFIX = "[%(real_name)s %%d]" # for numbering
 DEFAULT_MSG_HEADER = ""
 DEFAULT_MSG_FOOTER = """_______________________________________________
 %(real_name)s mailing list
@@ -810,6 +843,20 @@ DEFAULT_MSG_FOOTER = """_______________________________________________
 %(web_page_url)slistinfo%(cgiext)s/%(_internal_name)s
 """
 
+# Where to put subject prefix for 'Re:' messages:
+#
+#     old style: Re: [prefix] test
+#     new style: [prefix 123] Re: test ... (number is optional)
+#
+# Old style is default for backward compatibility.  New style is forced if a
+# list owner set %d (numbering) in prefix.  If the site owner had applied new
+# style patch (from SF patch area) before, he/she may want to set this No in
+# mm_cfg.py.
+OLD_STYLE_PREFIXING = Yes
+
+# Scrub regular delivery
+DEFAULT_SCRUB_NONDIGEST = False
+
 # Mail command processor will ignore mail command lines after designated max.
 DEFAULT_MAIL_COMMANDS_MAX_LINES = 25
 
@@ -820,6 +867,9 @@ DEFAULT_ADMIN_IMMED_NOTIFY = Yes
 # Is the list owner notified of subscribes/unsubscribes?
 DEFAULT_ADMIN_NOTIFY_MCHANGES = No
 
+# Discard held messages after this days
+DEFAULT_MAX_DAYS_TO_HOLD = 0
+
 # Should list members, by default, have their posts be moderated?
 DEFAULT_DEFAULT_MEMBER_MODERATION = No
 
@@ -932,11 +982,24 @@ DEFAULT_FILTER_CONTENT = No
 # types regardless of subtype (jpeg, gif, etc.).
 DEFAULT_FILTER_MIME_TYPES = []
 
-# DEFAULT_PASS_MIME_TYPES is a list of MIME types to be passed through.  Format is the same as DEFAULT_FILTER_MIME_TYPES
+# DEFAULT_PASS_MIME_TYPES is a list of MIME types to be passed through.
+# Format is the same as DEFAULT_FILTER_MIME_TYPES
 DEFAULT_PASS_MIME_TYPES = ['multipart/mixed',
                            'multipart/alternative',
                            'text/plain']
 
+# DEFAULT_FILTER_FILENAME_EXTENSIONS is a list of filename extensions to be
+# removed. It is useful because many viruses fake their content-type as
+# harmless ones while keep their extension as executable and expect to be
+# executed when victims 'open' them.
+DEFAULT_FILTER_FILENAME_EXTENSIONS = [
+    'exe', 'bat', 'cmd', 'com', 'pif', 'scr', 'vbs', 'cpl'
+    ]
+
+# DEFAULT_PASS_FILENAME_EXTENSIONS is a list of filename extensions to be
+# passed through. Format is the same as DEFAULT_FILTER_FILENAME_EXTENSIONS.
+DEFAULT_PASS_FILENAME_EXTENSIONS = []
+
 # Whether text/html should be converted to text/plain after content filtering
 # is performed.  Conversion is done according to HTML_TO_PLAIN_TEXT_COMMAND
 DEFAULT_CONVERT_HTML_TO_PLAINTEXT = Yes
@@ -1116,7 +1179,7 @@ PENDINGDB_LOCK_DEBUGGING = Off
 # These directories are used to find various important files in the Mailman
 # installation.  PREFIX and EXEC_PREFIX are set by configure and should point
 # to the installation directory of the Mailman package.
-PYTHON          = '/usr/local/bin/python2.2'
+PYTHON          = '/usr/local/bin/python2.3'
 PREFIX          = '/usr/local/lib/mailman'
 EXEC_PREFIX     = '${prefix}'
 VAR_PREFIX      = '/var/spool/mailman'
@@ -1289,7 +1352,7 @@ add_language('sl',    _('Slovenian'),           'iso-8859-2')
 add_language('sv',    _('Swedish'),             'iso-8859-1')
 add_language('tr',    _('Turkish'),             'iso-8859-9')
 add_language('uk',    _('Ukrainian'),           'utf-8')
-add_language('zh_CN', _('Chinese (China)'),     'gb2312')
-add_language('zh_TW', _('Chinese (Taiwan)'),    'big5')
+add_language('zh_CN', _('Chinese (China)'),     'utf-8')
+add_language('zh_TW', _('Chinese (Taiwan)'),    'utf-8')
 
 del _
